@@ -96,7 +96,6 @@ initial_tab_new (char *profile /* adopts */)
 
   it->profile = profile;
   it->exec_argv = NULL;
-  it->title = NULL;
   it->working_dir = NULL;
   it->zoom = 1.0;
   it->zoom_set = FALSE;
@@ -110,7 +109,6 @@ initial_tab_free (InitialTab *it)
 {
   g_free (it->profile);
   g_strfreev (it->exec_argv);
-  g_free (it->title);
   g_free (it->working_dir);
   g_slice_free (InitialTab, it);
 }
@@ -595,30 +593,6 @@ option_load_config_cb (const gchar *option_name,
   return result;
 }
 
-static gboolean
-option_title_callback (const gchar *option_name,
-                       const gchar *value,
-                       gpointer     data,
-                       GError     **error)
-{
-  TerminalOptions *options = data;
-
-  if (options->initial_windows)
-    {
-      InitialTab *it = ensure_top_tab (options);
-
-      g_free (it->title);
-      it->title = g_strdup (value);
-    }
-  else
-    {
-      g_free (options->default_title);
-      options->default_title = g_strdup (value);
-    }
-
-  return TRUE;
-}
-
 static gboolean
 option_working_directory_callback (const gchar *option_name,
                                    const gchar *value,
@@ -789,7 +763,6 @@ terminal_options_parse (const char *working_directory,
   options->initial_windows = NULL;
   options->default_role = NULL;
   options->default_geometry = NULL;
-  options->default_title = NULL;
   options->zoom = 1.0;
   options->zoom_set = FALSE;
 
@@ -928,7 +901,6 @@ terminal_options_merge_config (TerminalOptions *options,
 /*          it->width = g_key_file_get_integer (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_WIDTH, NULL);
           it->height = g_key_file_get_integer (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_HEIGHT, NULL);*/
           it->working_dir = terminal_util_key_file_get_string_unescape (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_WORKING_DIRECTORY, NULL);
-          it->title = g_key_file_get_string (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_TITLE, NULL);
 
           if (g_key_file_has_key (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_COMMAND, NULL) &&
               !(it->exec_argv = terminal_util_key_file_get_argv (key_file, tab_group, TERMINAL_CONFIG_TERMINAL_PROP_COMMAND, NULL, error)))
@@ -985,7 +957,6 @@ terminal_options_free (TerminalOptions *options)
   g_free (options->default_role);
   g_free (options->default_geometry);
   g_free (options->default_working_dir);
-  g_free (options->default_title);
   g_free (options->default_profile);
 
   g_strfreev (options->exec_argv);
@@ -1156,11 +1127,10 @@ get_goption_context (TerminalOptions *options)
     {
       "title",
       't',
-      0,
+      G_OPTION_FLAG_HIDDEN,
       G_OPTION_ARG_CALLBACK,
-      option_title_callback,
-      N_("Set the terminal title"),
-      N_("TITLE")
+      unsupported_option_callback,
+      NULL, NULL
     },
     {
       "working-directory",
